==> kibana-6.4.1.tgz: kibana/src/server/saved_objects/routes/bulk_get.js <==
'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBulkGetRoute = undefined;

var _joi = require('joi');

var _joi2 = _interopRequireDefault(_joi);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const createBulkGetRoute = exports.createBulkGetRoute = prereqs => ({
  path: '/api/saved_objects/_bulk_get',
  method: 'POST',
  config: {
    pre: [prereqs.getSavedObjectsClient],
    validate: {
      payload: _joi2.default.array().items(_joi2.default.object({
        type: _joi2.default.string().required(),
        id: _joi2.default.string().required()
      }).required())
    },
    handler(request, reply) {
      const { savedObjectsClient } = request.pre;

      reply(savedObjectsClient.bulkGet(request.payload));
    }
  }
}); /*
     * Licensed to Elasticsearch B.V. under one or more contributor
     * license agreements. See the NOTICE file distributed with
     * this work for additional information regarding copyright
     * ownership. Elasticsearch B.V. licenses this file to you under
     * the Apache License, Version 2.0 (the "License"); you may
     * not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *    http://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing,
     * software distributed under the License is distributed on an
     * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
     * KIND, either express or implied.  See the License for the
     * specific language governing permissions and limitations
     * under the License.
     */

==> kibana-6.6.1p1.tgz: kibana/src/server/saved_objects/routes/bulk_get.js <==
'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBulkGetRoute = undefined;

var _joi = require('joi');

var _joi2 = _interopRequireDefault(_joi);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const createBulkGetRoute = exports.createBulkGetRoute = prereqs => ({
  path: '/api/saved_objects/_bulk_get',
  method: 'POST',
  config: {
    pre: [prereqs.getSavedObjectsClient],
    validate: {
      payload: _joi2.default.array().items(_joi2.default.object({
        type: _joi2.default.string().required(),
        id: _joi2.default.string().required()
      }).required())
    },
    handler(request) {
      const { savedObjectsClient } = request.pre;

      return savedObjectsClient.bulkGet(request.payload);
    }
  }
}); /*
     * Licensed to Elasticsearch B.V. under one or more contributor
     * license agreements. See the NOTICE file distributed with
     * this work for additional information regarding copyright
     * ownership. Elasticsearch B.V. licenses this file to you under
     * the Apache License, Version 2.0 (the "License"); you may
     * not use this file except in compliance with the License.
     * You may obtain a copy of the License at
     *
     *    http://www.apache.org/licenses/LICENSE-2.0
     *
     * Unless required by applicable law or agreed to in writing,
     * software distributed under the License is distributed on an
     * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
     * KIND, either express or implied.  See the License for the
     * specific language governing permissions and limitations
     * under the License.
     */
